#******************************************************************************
#
# Project ICI-Covid
#
# Obj: Econometric analyses at the extensive margin
#     (full sample + sub-sample)
#
# Authors: Lucas Jeanneau - Quitterie Roquebert - Marianne Tenand
#
# Last modified: 24/02/2021
#
#******************************************************************************

        
  # Beforehand: run 0.Data.R and 1.Variables.R 
  # --> create dataframe data_regression, which includes:
  #   a) A dummy equal to 1 when respondent receives help with ADL/IADL
  #   b) Control variables for the regression analysis


#### Packages for the program ####

library(corrplot)
library(mfx)
library(stargazer)
stargazer(modele, type= "text")
library(dplyr)
library(sandwich)
library(lmtest)

library(DescTools)


# Convert character variables into either numeric or factor ones #
df_estim = data_regression
list_var = setdiff(names(data_regression), c("Groupe", "idetab", "idsenior"))
for (v in list_var){
  df_estim[, v] = as.numeric(df_estim[, v])
}
df_estim$group = factor(df_estim$Groupe)

#Define list of control variables
control_var  = "moinsde76+de76a85+de91a95+plusde96+femme+aucundiplome+bacouplus+group+santesubj+alzheimer"


#### (1) Probit model - full sample ####
########################################

modele<-glm(as.formula(paste0("aideproche_v2 ~ ", control_var, "+ conjoint_1+conjoint_2+pasdenfant+enfantdanslaville+freresoeur+lucratif")), 
            family= binomial(link = "probit"), 
            data = df_estim)
summary(modele)

modele_mfx <- probitmfx(as.formula(paste0("aideproche_v2 ~ ", control_var, "+ conjoint_1+conjoint_2+pasdenfant+enfantdanslaville+freresoeur+lucratif")), 
                  atmean=FALSE, data = df_estim)
modele_mfx

stargazer(coeftest(modele,vcovCL, cluster = df_estim$idetab),modele_mfx$fit,
          type = "html",
          out = paste0(dropbox, out, "Extensive/1_probit_full.doc"),
          coef = list(0, modele_mfx$mfxest[,1]),
          se = list(0, modele_mfx$mfxest[,2]),
          intercept.bottom = F,
          intercept.top = T,
          digits=5,
          covariate.labels = c("Intercept","Age: [60;75]","Age: ]75;85]","Age: ]91;95]","Age: ]95+]"
                               ,"Woman"
                               ,"No diploma","Baccalaurat"
                               ,"No ADL restriction","Severely dependent"
                               ,"Positive subjective health"
                               ,"Alzheimer's disease"
                               ,"Alone","Partner at home"
                               ,"No child alive", "One child in the same city"
                               ,"Brother or sister alive"
                               ,"For-profit institution"))

#### Stratification #### 
######################

#### (2) With a Partner #### 

sub_spouse<-df_estim %>%
  filter(conjoint_1 == 0)

modele_spouse<-glm(as.formula(paste0("aideproche_v2 ~ ", control_var, "+conjoint_2+pasdenfant+enfantdanslaville+freresoeur+lucratif")), 
                   family= binomial(link = "probit"), 
                   data = sub_spouse)

modele_spouse_mfx<-probitmfx(as.formula(paste0("aideproche_v2 ~ ", control_var, "+conjoint_2+pasdenfant+enfantdanslaville+freresoeur+lucratif")), 
                      atmean=FALSE, data = sub_spouse)
modele_spouse_mfx

stargazer(coeftest(modele_spouse,vcovCL, cluster = sub_spouse$idetab),modele_spouse_mfx$fit,
                     type = "html",
                     out = paste0(dropbox, out, "Extensive/2_probit_spouse.doc"),
                     coef = list(0, modele_spouse_mfx$mfxest[,1]),
                     se = list(0, modele_spouse_mfx$mfxest[,2]),
                     intercept.bottom = F,
                     intercept.top = T,
                     digits=5,
                     covariate.labels = c("Intercept","Age: [60;75]","Age: ]75;85]","Age: ]91;95]","Age: ]95+]"
                                          ,"Woman"
                                          ,"No diploma","Baccalaurat"
                                          ,"No ADL restriction ","Severely dependent"
                                          ,"Positive subjective health"
                                          ,"Alzheimer's disease"
                                          ,"Partner at home"
                                          ,"No child alive", "At least a child in the same city"
                                          ,"Brother or sister alive"
                                          ,"For-profit institution"))


####  (3) Children, no spouse #### 

sub_child<-df_estim %>%
  filter(conjoint_1== 1 & enfant == 1)

model_child<-glm(as.formula(paste0("aideproche_v2 ~ ", control_var, "+enfantdanslaville+freresoeur+lucratif")), 
                 family= binomial(link = "probit"), 
                 data = sub_child)

model_child_mfx <- probitmfx(as.formula(paste0("aideproche_v2 ~ ", control_var, "+enfantdanslaville+freresoeur+lucratif")),
                  atmean=FALSE, 
                  data = sub_child)
model_child_mfx

stargazer(coeftest(model_child,vcovCL, cluster = sub_child$idetab ),model_child_mfx$fit,
                     type = "html",
                     out = paste0(dropbox, out, "Extensive/3_probit_child.doc"),
                     coef = list(0, model_child_mfx$mfxest[,1]),
                     se = list(0, model_child_mfx$mfxest[,2]),
                     intercept.bottom = F,
                     intercept.top = T,
                     digits=5,
                     covariate.labels = c("Intercept","Age: [60;75]","Age: ]75;85]","Age: ]91;95]","Age: ]95+]"
                                          ,"Woman"
                                          ,"No diploma","Baccalaurat"
                                          ,"No ADL restriction ","Severely dependent"
                                          ,"Positive subjective health"
                                          ,"Alzheimer's disease"
                                          ,"At least a child in the same city"
                                          ,"Brother or sister alive"
                                          ,"For-profit institution"))


#### (4) No children, no spouse #### 

sub_nobody<-df_estim %>%
  filter(conjoint_1== 1 & enfant == 0)

model_nobody<-glm(as.formula(paste0("aideproche_v2 ~ ", control_var, "+freresoeur+lucratif")),
                family= binomial(link = "probit"), 
                data = sub_nobody)

model_nobody_mfx <- probitmfx(as.formula(paste0("aideproche_v2 ~ ", control_var, "+freresoeur+lucratif")),
                    atmean=FALSE, data = sub_nobody)
model_nobody_mfx
                    
stargazer(coeftest(model_nobody,vcovCL, cluster = sub_nobody$idetab),model_nobody_mfx$fit,
                     type = "html",
                     out = paste0(dropbox, out, "Extensive/4_probit_nobody.doc"),
                     coef = list(NULL, model_nobody_mfx$mfxest[,1]),
                     se = list(NULL, model_nobody_mfx$mfxest[,2]),
                     intercept.bottom = F,
                     intercept.top = T,
                     digits=5,
                     covariate.labels = c("Intercept","Age: [60;75]","Age: ]75;85]","Age: ]91;95]","Age: ]95+]"
                                          ,"Woman"
                                          ,"No diploma","Baccalaurat"
                                          ,"No ADL restriction","Severely dependent"
                                          ,"Positive subjective health"
                                          ,"Alzheimer's disease"
                                          ,"Brother or sister alive"
                                          ,"For-profit institution"))

#### Synthetic table #### 
  # Marginal effects
stargazer(modele_mfx$fit,modele_spouse_mfx$fit,model_child_mfx$fit, model_nobody_mfx$fit,
                   type = "html",
                   out = paste0(dropbox, out, "Extensive/ICI-Covid_Table2.doc"),
                   coef = list(modele_mfx$mfxest[,1],modele_spouse_mfx$mfxest[,1],model_child_mfx$mfxest[,1],model_nobody_mfx$mfxest[,1]),
                   se = list(modele_mfx$mfxest[,2],modele_spouse_mfx$mfxest[,2],model_child_mfx$mfxest[,2],model_nobody_mfx$mfxest[,2]),
                   intercept.bottom = F,
                   intercept.top = T,
                   digits=5,
                   covariate.labels = c("Intercept","Age: [60;75]","Age: ]75;85]","Age: ]91;95]","Age: ]95+]"
                                        ,"Woman"
                                        ,"No diploma","Baccalaurat"
                                        ,"No ADL restriction","Severely dependent"
                                        ,"Positive subjective health"
                                        ,"Alzheimer's disease"
                                        ,"Alone","Partner at home"
                                        ,"No child alive", "At least a child in the same city"
                                        ,"Brother or sister alive"
                                        ,"For-profit institution"))  